@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/cench/sentry-10-dingding'
-    version = sentry_dingding.VERSION
+    version = '1.0.4'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/cench/sentry-10-dingding'),
@@ -60,7 +60,7 @@ class DingDingPlugin(NotificationPlugin):
                 "title": title,
                 "text": u"#### {title} \n\n > {title} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
-                    path=event.tags.url,
+                    path=event.get_tag('url'),
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
